@@ -5,9 +5,10 @@ check_raster_specials <- function(x, g, gt, shpcols, data, nx) {
 	# 	nx <- 1
 	# 	x <- setdiff(names(data), c("tmapfilter", "GROUP_BY", "ALONG"))
 	# } else 
+	pc = list(sepia.intensity = gt$pc$sepia.intensity, saturation = g$saturation * gt$pc$saturation)
 	if ("PIXEL__COLOR" %in% names(data)) {
 		x <- "PIXEL__COLOR"
-		data$PIXEL__COLOR <- do.call("process_color", c(list(col=data$PIXEL__COLOR, alpha=g$alpha), gt$pc))
+		data$PIXEL__COLOR <- do.call("process_color", c(list(col=data$PIXEL__COLOR, alpha=g$alpha), pc))
 		is.colors <- TRUE
 		nx <- 1
 	} else if ("FILE__VALUES" %in% names(data)) {
@@ -40,7 +41,7 @@ check_raster_specials <- function(x, g, gt, shpcols, data, nx) {
 			is.colors <- all(valid_colors(x))
 			if (!is.colors) stop("Invalid color specification. The available raster variables are: \"", paste(attr(data, "shpnames"), collapse = "\", \""), "\"." , call. = FALSE)
 			
-			x <- do.call("process_color", c(list(col=col2hex(x), alpha=g$alpha), gt$pc))
+			x <- do.call("process_color", c(list(col=col2hex(x), alpha=g$alpha), pc))
 			for (i in 1:nx) data[[paste("COLOR", i, sep="_")]] <- x[i]
 			x <- paste("COLOR", 1:nx, sep="_")
 		}
